/*jslint undef: true, widget: true, browser: true, onevar: true, eqeqeq: true */
/*global $ iw_lib iw_xhr updateServiceStatus iw_ctrl_handler iw_js_data*/

/**
 *
 */
let iw_service_running_handler = {
    action: 'isRunning',
    status_success: IW.states.POSITIVE,
    status_fail: IW.states.NEGATIVE,
    status_disabled: IW.states.DISABLED,
    extractCtrlName: function ( el ) {
        let first_colon = $(el).attr('id').indexOf(':');

        first_colon = ( first_colon === -1 ) ? $(el).attr('id').length : first_colon;
        return $(el).attr('id').substring(7, first_colon);
    },
    extractNodeId: function ( el ) {
        let first_colon = $(el).attr('id').indexOf(':');

        first_colon = ( first_colon === -1 ) ? $(el).attr('id').length : first_colon;

        if ( first_colon === $(el).attr('id').length ) {
            return null;
        } else {
            return $(el).attr('id').substring(first_colon + 1);
        }
    },
    execute: function (el) {
        let ctrl           = this.extractCtrlName(el),
            node_id        = this.extractNodeId(el),
            status_success = this.status_success,
            status_fail    = this.status_fail,
            callback_obj,
            action         = this.action,
            input          = {iw_payload_output: 'json'};

        if (node_id) {
            input.node_id = node_id;
            action = action + 'OnNodeCommit';
        }

        if (iw_js_data.iw_env.is_node) {
            input.enable_local_changes = 1;
        }

        callback_obj = {
            args: el,
            callback: function ( reply, success, el ) {
                let data = reply.getReplyData();

                if ( reply.getReplyCode() === 201 ) {
                    if ( data === true ) {
                        updateServiceStatus({ el: el, new_class: status_success });
                    } else {
                        updateServiceStatus({ el: el, new_class: status_fail });
                    }
                } else {
                    updateServiceStatus({ el: el,
                        new_class: status_fail,
                        message: data.message
                               });
                }
            }
        };

        ctrl = ctrl.replace(/-/g, '/');
        iw_ctrl_handler.execute(null, callback_obj, ctrl, action, input);
    }
};

/**
 *
 */
var iw_start_handler         = Object.beget(iw_service_running_handler);
iw_start_handler.action      = 'startCommit';
iw_start_handler.node_action = 'startOnNodeCommit';
iw_start_handler.isDisabled  = function (el_service) {
    return (!$(el_service).hasClass(IW.states.NEGATIVE));
};
iw_start_handler.execute = function (e) {
    let target         = e.target,
        parent         = $(target).closest('.iw-service')[0],
        ctrl           = this.extractCtrlName(parent),
        action         = this.action,
        status_success = this.status_success,
        status_fail    = this.status_fail,
        cascade_no     = -1,
        cascade_yes    = 1,
        cascade_prompt = 0,
        callback_obj,
        cascade,
        yes_handler,
        no_handler,
        confirm_dialog,
        input,
        node_id        = this.extractNodeId(parent);

    e.stopPropagation();
    e.preventDefault();

    if ( node_id ) {
        action = this.node_action;
    }

    if ( this.isDisabled(parent) === false ) {
        updateServiceStatus({ el: parent, new_class: this.status_disabled });
        callback_obj = {
            args: parent,
            callback: function ( reply, success, el ) {
                if ( success === true ) {
                    updateServiceStatus({ el: el, new_class: status_success });
                } else {
                    updateServiceStatus({ el: el, new_class: status_fail });
                }
            }
        };

        ctrl = ctrl.replace(/-/g, '/');

        yes_handler = function () {
            input = {node_id: node_id,
                cascade_to_nodes: '1',
                security_token: iw_js_data.iw_env.security_token};
            iw_ctrl_handler.execute(null, callback_obj, ctrl, action, input);
            this.hide();
        };

        no_handler = function ( do_not_hide ) {
            if ( do_not_hide !== true ) {
                do_not_hide = false;
            }

            input = {node_id: node_id,
                security_token: iw_js_data.iw_env.security_token,
                enable_local_changes: iw_js_data.iw_env.is_node };
            iw_ctrl_handler.execute(null, callback_obj, ctrl, action, input);

            if ( do_not_hide === false ) {
                this.hide();
            }
        };

        if ( typeof( iw_js_data.service_cascade ) !== "undefined" &&
        iw_js_data.service_cascade !== null ) {
            cascade = iw_js_data.service_cascade;
        } else {
            if ( iw_js_data.iw_env.is_manager ) {
                cascade = cascade_prompt;
            } else {
                cascade = cascade_no;
            }
        }

        // TIMDO - when dealing with IWX-6489
        if ( iw_js_data.iw_env.is_manager && !node_id && cascade === cascade_prompt ) {
            confirm_dialog = new YAHOO.widget.SimpleDialog(
                "iw-confirm",
                { width: "300px",
                    fixedcenter: true,
                    visible: true,
                    draggable: false,
                    close: false,
                    modal: true,
                    text: '##LG_CASCADE_TO_NODES##<br><br>##LG_QH_CASCADE_TO_NODES_YES_NO##',
                    icon: YAHOO.widget.SimpleDialog.ICON_HELP,
                    constraintoviewport: true,
                    buttons: [ { text:'##LG_YES##', handler:yes_handler, isDefault:true },
                    { text:'##LG_NO##',  handler:no_handler } ]
                }
            );

            confirm_dialog.setHeader('##LG_CONFIRM_ACTION##');
            confirm_dialog.render(document.body);
        } else if ( cascade === cascade_yes ) {
            yes_handler();
        } else if ( cascade === cascade_no ) {
            no_handler(true);
        }//end if
    }//end if
};

/**
 *
 */
var iw_restart_handler         = Object.beget(iw_start_handler);
iw_restart_handler.action      = 'restartCommit';
iw_restart_handler.node_action = 'restartOnNodeCommit';
iw_restart_handler.isDisabled  = function ( el_service ) {
    return !$(el_service).hasClass(IW.states.POSITIVE);
};

/**
 *
 */
var iw_stop_handler            = Object.beget(iw_restart_handler);
iw_stop_handler.action         = 'stopCommit';
iw_stop_handler.node_action    = 'stopOnNodeCommit';
iw_stop_handler.status_success = IW.states.NEGATIVE;
iw_stop_handler.status_fail    = IW.states.POSITIVE;

/**
 * TODO: write me
 */
function enableRefresh()
{
    document.getElementById('iw-svc-refresh').disabled = 0;
}

/**
 * TODO: write me
 */
function refreshServices( e )
{
    let i,
      target,
      service_statuses,
      service_statuses_length,
      mybox;

    e = e || null;
    if (e) {
        e.stopPropagation();
        e.preventDefault();
        target          = e.target;
        target.disabled = 1;
        setTimeout(enableRefresh, 10000);
    }

    service_statuses = $('.iw-service');

    service_statuses_length = service_statuses.length;

    for (i = 0; i < service_statuses_length; ++i) {
        mybox = $(service_statuses[i]).closest('.iw-box');
        if ( !mybox || !$(mybox).hasClass('iw-closed')) {
            updateServiceStatus({ el: service_statuses[ i ], new_class: iw_service_running_handler.status_disabled });
            $('#ft').ready(
                $.proxy(
                    iw_service_running_handler.execute,
                    iw_service_running_handler,
                    service_statuses[i]
                )
            );
        }
    }
}

/**
 * TODO: write me
 */
function updateServiceStatus( input )
{
    let el        = input.el,
        new_class = input.new_class || null,
        msg       = input.message || null,
        message_v = '<span title="##LG_STATUS##" class="iw-svc-status"><i class="mdi mdi-loading mdi-spin"></i></span>',
        target,
        ctrl,
        status_el,
        status_img,
        img_class,
        status_v_el,
        node_id;

    if (new_class) {
        target = $('i', el)[0];
        switch ( new_class ) {
            case IW.states.DISABLED:
                target.title = '##LG_PENDING##';
                img_class    = IW.icons.PENDING;
            break;

            case iw_service_running_handler.status_success:
                target.title = '##LG_RUNNING##';
                img_class    = IW.icons.POSITIVE;
                message_v    = target.title;
            break;

            case iw_service_running_handler.status_fail:
                target.title = '##LG_STOPPED##';
                img_class    = IW.icons.ALERT_CIRCLE;
                message_v    = target.title;

                if (msg) {
                    target.title = '##LG_UNKNOWN##';
                    img_class    = IW.icons.ALERT;
                    message_v    = '##LG_UNKNOWN##';
                }

            break;
        }//end switch
    }//end if

    ctrl    = iw_service_running_handler.extractCtrlName(el);
    node_id = iw_service_running_handler.extractNodeId(el);

    if ( node_id ) {
        ctrl = ctrl + ':' + node_id;
    }

    status_el   = document.getElementById('iw-stat-' + ctrl);
    status_v_el = document.getElementById('iw-stat-v-' + ctrl);

    // update the status
    if ( status_el ) {
        iw_lib.updateIWMessage({el: status_el, new_class: input.new_class});

        status_img = status_el.getElementsByTagName('i');
        status_img = status_img[0];

        iw_lib.updateIWIcon(status_img, img_class);
    }
    // update the verbose status
    if (status_v_el) {
        iw_lib.updateIWMessage(
            {
                el       : status_v_el,
                new_class: input.new_class,
                message  : message_v
            }
        );
    }
    // Update the control itself
    iw_lib.updateIWMessage(input);

    // fire the event if we're updating to non-disabled mode
    if ( new_class !== 'iw-disabled' ) {
        $('.iw-svc-stat-v').trigger('onServiceStatusUpdate');
    }
}

/**
 * Connect the refresh button to the refreshServices func
 */
$('#iw-svc-refresh').click(refreshServices);

/**
 * Connect listeners to the start/stop/restart controls
 */
$('.' + IW.icons.START).click($.proxy(iw_start_handler.execute, iw_start_handler));
$('.' + IW.icons.RESTART).click($.proxy(iw_restart_handler.execute, iw_restart_handler));
$('.' + IW.icons.STOP).click($.proxy(iw_stop_handler.execute, iw_stop_handler));

/**
 * When the page first loads, refresh the service status(es)
 */
refreshServices();
